@@ -59,6 +59,7 @@ module Aws::CloudTrail
   # * {InsightNotEnabledException}
   # * {InsufficientDependencyServiceAccessPermissionException}
   # * {InsufficientEncryptionPolicyException}
+  # * {InsufficientIAMAccessPermissionException}
   # * {InsufficientS3BucketPolicyException}
   # * {InsufficientSnsTopicPolicyException}
   # * {InvalidCloudWatchLogsLogGroupArnException}
@@ -439,6 +440,16 @@ module Aws::CloudTrail
       end
     end
 
+    class InsufficientIAMAccessPermissionException < ServiceError
+
+      # @param [Seahorse::Client::RequestContext] context
+      # @param [String] message
+      # @param [Aws::CloudTrail::Types::InsufficientIAMAccessPermissionException] data
+      def initialize(context, message, data = Aws::EmptyStructure.new)
+        super(context, message, data)
+      end
+    end
+
     class InsufficientS3BucketPolicyException < ServiceError
 
       # @param [Seahorse::Client::RequestContext] context
