@@ -256,8 +256,8 @@ module Aws::RDS
       data[:snapshot_database_time]
     end
 
-    # Specifies where manual snapshots are stored: Amazon Web Services
-    # Outposts or the Amazon Web Services Region.
+    # Specifies where manual snapshots are stored: Dedicated Local Zones,
+    # Amazon Web Services Outposts or the Amazon Web Services Region.
     # @return [String]
     def snapshot_target
       data[:snapshot_target]
@@ -292,6 +292,14 @@ module Aws::RDS
       data[:multi_tenant]
     end
 
+    # Specifies the name of the Availability Zone where RDS stores the DB
+    # snapshot. This value is valid only for snapshots that RDS stores on a
+    # Dedicated Local Zone.
+    # @return [String]
+    def snapshot_availability_zone
+      data[:snapshot_availability_zone]
+    end
+
     # @!endgroup
 
     # @return [Client]
@@ -485,6 +493,8 @@ module Aws::RDS
     #     option_group_name: "String",
     #     target_custom_availability_zone: "String",
     #     copy_option_group: false,
+    #     snapshot_availability_zone: "String",
+    #     snapshot_target: "String",
     #     source_region: "String",
     #   })
     # @param [Hash] options ({})
@@ -631,6 +641,20 @@ module Aws::RDS
     #   source DB snapshot to the target Amazon Web Services account and
     #   associate with the target DB snapshot. The associated option group can
     #   be copied only with cross-account snapshot copy calls.
+    # @option options [String] :snapshot_availability_zone
+    #   Specifies the name of the Availability Zone where RDS stores the DB
+    #   snapshot. This value is valid only for snapshots that RDS stores on a
+    #   Dedicated Local Zone.
+    # @option options [String] :snapshot_target
+    #   Configures the location where RDS will store copied snapshots.
+    #
+    #   Valid Values:
+    #
+    #   * `local` (Dedicated Local Zone)
+    #
+    #   * `outposts` (Amazon Web Services Outposts)
+    #
+    #   * `region` (Amazon Web Services Region)
     # @option options [String] :source_region
     #   The source region of the snapshot. This is only needed when the
     #   shapshot is encrypted and in a different region.
@@ -813,7 +837,7 @@ module Aws::RDS
     #   License model information for the restored DB instance.
     #
     #   <note markdown="1"> License models for RDS for Db2 require additional configuration. The
-    #   Bring Your Own License (BYOL) model requires a custom parameter group
+    #   bring your own license (BYOL) model requires a custom parameter group
     #   and an Amazon Web Services License Manager self-managed license. The
     #   Db2 license through Amazon Web Services Marketplace model requires an
     #   Amazon Web Services Marketplace subscription. For more information,
@@ -1139,8 +1163,9 @@ module Aws::RDS
     #   Specifies where automated backups and manual snapshots are stored for
     #   the restored DB instance.
     #
-    #   Possible values are `outposts` (Amazon Web Services Outposts) and
-    #   `region` (Amazon Web Services Region). The default is `region`.
+    #   Possible values are `local` (Dedicated Local Zone), `outposts` (Amazon
+    #   Web Services Outposts), and `region` (Amazon Web Services Region). The
+    #   default is `region`.
     #
     #   For more information, see [Working with Amazon RDS on Amazon Web
     #   Services Outposts][1] in the *Amazon RDS User Guide*.
@@ -1241,8 +1266,8 @@ module Aws::RDS
     #   You can use this setting to enroll your DB instance into Amazon RDS
     #   Extended Support. With RDS Extended Support, you can run the selected
     #   major engine version on your DB instance past the end of standard
-    #   support for that engine version. For more information, see [Using
-    #   Amazon RDS Extended Support][1] in the *Amazon RDS User Guide*.
+    #   support for that engine version. For more information, see [Amazon RDS
+    #   Extended Support with Amazon RDS][1] in the *Amazon RDS User Guide*.
     #
     #   This setting applies only to RDS for MySQL and RDS for PostgreSQL. For
     #   Amazon Aurora DB instances, the life cycle type is managed by the DB
